<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Display the final payment of the part payments checkout form.
 *
 * @param string $output
 * @param WPBS_Payment $payment
 * @param string $language
 *
 * @return string
 *
 */
function wpbs_final_payment_redsys($output, $payment, $language)
{

    // Get total amount
    $total = $payment->get_total_second_payment();

    // Include Redsys API
    include_once WPBS_REDSYS_PLUGIN_DIR . 'includes/libs/redsys-api/redsys-api.php';

    $api = WPBS_Redsys_API::keys();

    // Check for API Keys
    if (empty($api['merchant_code']) || empty($api['api_key'])) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<p class="wpbs-form-general-error">' . __("Please add your API keys in the plugin's Settings Page.", 'wp-booking-system-redsys') . '</p>',
            )
        );
    }

    /**
     * Create the Payment Intent on Redsys
     *
     */
    $return_url = get_permalink() . '?wpbs-payment-id=' . $_GET['wpbs-payment-id'] . '&wpbs-redsys-deposit';

    $booking_data = array('order_id' => $payment->get('id'), 'language' => $language);

    // Generate an unique ID for the transient id
    $booking_data_transient_id = substr(uniqid(), 1, 12);

    set_transient($booking_data_transient_id, $booking_data, DAY_IN_SECONDS * 7);

    $remote_payment_method = $payment->get('gateway') == 'redsys_bizum' ? 'z' : '';

    $redsys = new WPBS_Redsys_Payment();
    $redsys_payment = $redsys->createPaymentRequest($total * 100, $booking_data_transient_id, $return_url, $remote_payment_method);

    /**
     * Prepare Response
     *
     */

    $output = '';
    if ($api['production_mode'] == false) {
        $output .= '<p class="wpbs-payment-test-mode-enabled">' . __('Redsys Test mode is enabled.', 'wp-booking-system-redsys') . '</p>';
    }

    $output .= '<div class="wpbs-payment-confirmation-redsys-form">';

    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $output .= '<label>' . wpbs_get_payment_default_string('amount_billed', $language) . '</label><input class="wpbs-payment-confirmation-redsys-input" type="text" value="' . wpbs_get_formatted_price($total, $payment->get_currency()) . '" readonly>';
    }

    $output .= $redsys_payment->form(false, wpbs_get_payment_default_string('payment_submit', $language));

    $output .= '<div class="wpbs-redsys-powered-by"><img src="' . WPBS_REDSYS_PLUGIN_DIR_URL . 'assets/img/redsys-logo.png"></div>';

    $output .= '</div>';

    return $output;

}
add_filter('wpbs_final_payment_redsys', 'wpbs_final_payment_redsys', 10, 3);
add_filter('wpbs_final_payment_redsys_bizum', 'wpbs_final_payment_redsys', 10, 3);

/**
 * Show a message when the payment failed.
 *
 */
function wpbs_redsys_form_outputter_final_payment_failed()
{
    // Check if we're on the redsys confirmation page
    if (!isset($_GET['wpbs-redsys-deposit'])) {
        return false;
    }

    if (!isset($_GET['wpbs_redsys_payment_failed'])) {
        return false;
    }

    // Replace the form with the confirmation message
    add_filter('wpbs_final_payment_output', function ($output) {
        return '
        <script>jQuery(document).ready(function(){
            if(jQuery("#wpbs-payment-error-message").length){
                jQuery("html, body").scrollTop(jQuery("#wpbs-payment-error-message").offset().top);
            }
        });</script>
        <div class="wpbs-main-wrapper"><p class="wpbs-payment-error-message" id="wpbs-payment-error-message">The payment was declined. Your credit card was not charged. <a href="' . get_permalink() . '?wpbs-payment-id=' . $_GET['wpbs-payment-id'] . '">Please try again.</a></p></div>';
    });

}
add_action('init', 'wpbs_redsys_form_outputter_final_payment_failed', 20);

/**
 * Show a message when the payment succeeded.
 *
 */
function wpbs_redsys_form_outputter_final_payment_succeeded()
{
    // Check if we're on the redsys confirmation page
    if (!isset($_GET['wpbs-redsys-deposit'])) {
        return false;
    }

    if (!isset($_GET['wpbs_redsys_payment_succeeded'])) {
        return false;
    }

    global $response;
    $response = get_transient($_GET['wpbs_redsys_order_id'] . '_response');

    if (!$response) {
        add_filter('wpbs_form_outputter_form', function ($output) {
            $confirmation = '<script>jQuery(document).ready(function(){
                if(jQuery("#wpbs-payment-success-message").length){
                    jQuery("html, body").scrollTop(jQuery("#wpbs-payment-success-message").offset().top);
                }
                setTimeout(function(){
                    window.location.reload();
                }, 3000);
            });</script>
            <div id="wpbs-payment-success-message">
            <p>'.wpbs_get_payment_default_string('processing_payment', wpbs_get_locale()).'</p>
            </div>';

            return $confirmation;
        });
        return false;
    }

    if(isset($response['received'])){
        return false;
    }

    $response['received'] = true;
    set_transient($_GET['wpbs_redsys_order_id'] . '_response', $response, DAY_IN_SECONDS);

    // Replace the form with the confirmation message
    add_filter('wpbs_final_payment_output', function ($output) {
        global $response;
         
        return '<script>jQuery(document).ready(function(){
            if(jQuery("#wpbs-payment-success-message").length){
                jQuery("html, body").scrollTop(jQuery("#wpbs-payment-success-message").offset().top);
            }
        });</script><div id="wpbs-payment-success-message">' . $response . '</div>';
    });

}
add_action('init', 'wpbs_redsys_form_outputter_final_payment_succeeded', 20);

/**
 * The final payment webhook
 *
 */
function wpbs_redsys_final_payment_webhook()
{

    // Check if we're on the redsys confirmation page
    if (!isset($_GET['wpbs-redsys-deposit'])) {
        return false;
    }

    if (!isset($_GET['wpbs_redsys_payment_webhook'])) {
        return false;
    }

    // Include Redsys API
    include_once WPBS_REDSYS_PLUGIN_DIR . 'includes/libs/redsys-api/redsys-api.php';

    // Get Payment Details
    $redsys_payment = new WPBS_Redsys_Payment();
    $payment_data = $redsys_payment->getPaymentData();

    if (!isset($payment_data['status'])) {
        return false;
    }

    if ($payment_data['status'] != 'succeeded') {
        return false;
    }

    // Exit if no additional parameters were sent.
    if (!isset($payment_data['order'])) {
        return false;
    }

    // Get booking data from transient
    $booking_data = get_transient($payment_data['order']);

    // Check if booking data exists
    if (empty($booking_data)) {
        return false;
    }

    $language = $booking_data['language'];

    // Get the order ID from the Redsys response
    $order_id = $booking_data['order_id'];

    // Get the order from the database
    $payment = wpbs_get_payment($order_id);

    if (is_null($payment)) {
        return false;
    }

    // Get site options
    $settings = get_option('wpbs_settings', array());

    // Get price
    $details = $payment->get('details');

    // Check if final payment wasn't made yet
    if ($payment->is_final_payment_paid()) {
        return false;
    }

    // If the payment succeeded
    $details['final_payment'] = $payment_data;
    $details['part_payments']['final_payment'] = true;

    $details['raw']['authorisation_code'] .= ', ' . $payment_data['authorisation_code'];
    $details['raw']['amount'] = $details['raw']['amount'] + $payment_data['amount'];

    $status = 'completed';

    // Create the output containing the confirmation message and the tracking script
    $confirmation_message = (!empty($settings['payment_part_payments_confirmation_translation_' . $language])) ? $settings['payment_part_payments_confirmation_translation_' . $language] : (!empty($settings['payment_part_payments_confirmation']) ? $settings['payment_part_payments_confirmation'] : __('The form was successfully submitted.', 'wp-booking-system'));

    global $form_output;
    $form_output = apply_filters('the_content', $confirmation_message);

    $order_data = array(
        'order_status' => $status,
        'details' => $details,
    );

    // Save Order
    wpbs_update_payment($payment->get('id'), $order_data);

    do_action('wpbs_save_final_payment', $payment);

    // Save response for displaying in the form
    set_transient($payment_data['order'] . '_response', $form_output, DAY_IN_SECONDS * 7);
}
add_action('init', 'wpbs_redsys_final_payment_webhook', 20);
