<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Includes the Base files
 *
 */
function wpbs_redsys_include_files_base()
{
    // Get legend dir path
    $dir_path = plugin_dir_path(__FILE__);

    // Include Payment Ajax Functions
    if (file_exists($dir_path . 'functions-actions-redsys.php')) {
        include $dir_path . 'functions-actions-redsys.php';
    }

    // Include Part Payments Functions
    if (file_exists($dir_path . 'functions-part-payments.php')) {
        include $dir_path . 'functions-part-payments.php';
    }
}
add_action('wpbs_redsys_include_files', 'wpbs_redsys_include_files_base');

/**
 * Register Payment Method
 *
 * @param array
 *
 */
function wpbs_redsys_register_payment_method($payment_methods)
{
    $settings = get_option('wpbs_settings', array());

    $payment_methods['redsys'] = 'Redsys';
    $payment_methods['redsys_bizum'] = 'BIZUM';
    return $payment_methods;
}
add_filter('wpbs_payment_methods', 'wpbs_redsys_register_payment_method');

/**
 * Default form values
 *
 */
function wpbs_redsys_settings_redsys_defaults()
{
    return array(
        'display_name' => __('Redsys', 'wp-booking-system-redsys'),
        'description' => __('Pay with your credit card through Redsys.', 'wp-booking-system-redsys'),
        'display_name_bizum' => __('BIZUM', 'wp-booking-system-redsys'),
        'description_bizum' => __('Pay through BIZUM.', 'wp-booking-system-redsys'),
    );
}

/**
 * Check if payment method is enabled in settings page
 *
 */
function wpbs_redsys_form_outputter_payment_method_enabled_redsys($active)
{
    $settings = get_option('wpbs_settings', array());
    if (isset($settings['payment_redsys_enable']) && $settings['payment_redsys_enable'] == 'on') {
        return true;
    }
    return false;
}
add_filter('wpbs_form_outputter_payment_method_enabled_redsys', 'wpbs_redsys_form_outputter_payment_method_enabled_redsys');

/**
 * Check if payment method is enabled in settings page
 *
 */
function wpbs_redsys_form_outputter_payment_method_enabled_redsys_bizum($active)
{
    $settings = get_option('wpbs_settings', array());
    if (isset($settings['payment_redsys_bizum_enable']) && $settings['payment_redsys_bizum_enable'] == 'on') {
        return true;
    }
    return false;
}
add_filter('wpbs_form_outputter_payment_method_enabled_redsys_bizum', 'wpbs_redsys_form_outputter_payment_method_enabled_redsys_bizum');

/**
 * Get the payment method's name
 *
 */
function wpbs_redsys_form_outputter_payment_method_name_redsys($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_redsys_name_translation_' . $language])) {
        return $settings['payment_redsys_name_translation_' . $language];
    }
    if (!empty($settings['payment_redsys_name'])) {
        return $settings['payment_redsys_name'];
    }
    return wpbs_redsys_settings_redsys_defaults()['display_name'];
}
add_filter('wpbs_form_outputter_payment_method_name_redsys', 'wpbs_redsys_form_outputter_payment_method_name_redsys', 10, 2);

/**
 * Get the payment method's name
 *
 */
function wpbs_redsys_form_outputter_payment_method_name_redsys_bizum($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_redsys_bizum_name_translation_' . $language])) {
        return $settings['payment_redsys_bizum_name_translation_' . $language];
    }
    if (!empty($settings['payment_redsys_bizum_name'])) {
        return $settings['payment_redsys_bizum_name'];
    }
    return wpbs_redsys_settings_redsys_defaults()['display_name_bizum'];
}
add_filter('wpbs_form_outputter_payment_method_name_redsys_bizum', 'wpbs_redsys_form_outputter_payment_method_name_redsys_bizum', 10, 2);

/**
 * Get the payment method's name
 *
 */
function wpbs_redsys_form_outputter_payment_method_description_redsys($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_redsys_description_translation_' . $language])) {
        return $settings['payment_redsys_description_translation_' . $language];
    }
    if (!empty($settings['payment_redsys_description'])) {
        return $settings['payment_redsys_description'];
    }
    return wpbs_redsys_settings_redsys_defaults()['description'];
}
add_filter('wpbs_form_outputter_payment_method_description_redsys', 'wpbs_redsys_form_outputter_payment_method_description_redsys', 10, 2);

/**
 * Get the payment method's name
 *
 */
function wpbs_redsys_form_outputter_payment_method_description_redsys_bizum($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_redsys_bizum_description_translation_' . $language])) {
        return $settings['payment_redsys_bizum_description_translation_' . $language];
    }
    if (!empty($settings['payment_redsys_bizum_description'])) {
        return $settings['payment_redsys_bizum_description'];
    }
    return wpbs_redsys_settings_redsys_defaults()['description_bizum'];
}
add_filter('wpbs_form_outputter_payment_method_description_redsys_bizum', 'wpbs_redsys_form_outputter_payment_method_description_redsys_bizum', 10, 2);

/**
 * Add the supported currencies by Redsys
 * 
 * @param array $currencies
 * 
 * @return array
 * 
 */
function wpbs_redsys_currencies($currencies = array())
{
    $currencies['EUR'] = 'Euros';

    return $currencies;
}
add_filter('wpbs_currencies', 'wpbs_redsys_currencies', 10, 1);

/**
 * Make strings translatable - add default strings
 *
 */
function wpbs_redsys_payment_default_strings($strings)
{
    $strings['payment_submit']  = __('Submit', 'wp-booking-system-redsys');

    return $strings;
}
add_filter('wpbs_payment_default_strings', 'wpbs_redsys_payment_default_strings');

/**
 * Make strings translatable - add form fields strings
 *
 */
function wpbs_redsys_payment_default_strings_labels($strings)
{

    $strings['payment_submit'] = array(
        'label' => __('Payment Submit Button Label', 'wp-booking-system-redsys'),
        'tooltip' => __("The button label when submitting a payment form.", 'wp-booking-system-redsys'),
    );

    return $strings;
}
add_filter('wpbs_payment_default_strings_labels', 'wpbs_redsys_payment_default_strings_labels');