<?php

include_once WPBS_REDSYS_PLUGIN_DIR . 'includes/libs/redsys-api/vendor/autoload.php';

use Vguerrerobosch\Redsys\PaymentRequest;
use Vguerrerobosch\Redsys\Redsys;
use Vguerrerobosch\Redsys\Webhook as Webhook;

class WPBS_Redsys_API
{
    public static function keys()
    {
        $settings = get_option('wpbs_settings', array());
        $redsys_api = get_option('wpbs_redsys_api', array());

        if ((isset($settings['payment_redsys_test']) && $settings['payment_redsys_test'] == 'on')) {
            return array(
                'production_mode' => false,
                'merchant_code' => isset($redsys_api['payment_redsys_test_merchant_code']) ? $redsys_api['payment_redsys_test_merchant_code'] : '',
                'api_key' => isset($redsys_api['payment_redsys_test_api_key']) ? $redsys_api['payment_redsys_test_api_key'] : '',
                'terminal' => 1,
            );
        } else {
            return array(
                'production_mode' => true,
                'merchant_code' => isset($redsys_api['payment_redsys_live_merchant_code']) ? $redsys_api['payment_redsys_live_merchant_code'] : '',
                'api_key' => isset($redsys_api['payment_redsys_live_api_key']) ? $redsys_api['payment_redsys_live_api_key'] : '',
                'terminal' => isset($redsys_api['payment_redsys_live_terminal_id']) ? $redsys_api['payment_redsys_live_terminal_id'] : 1,
            );
        }
    }
}

class WPBS_Redsys_Payment
{
    public function createPaymentRequest($amount, $order_id, $return_url, $paymethods = '')
    {

        $api = WPBS_Redsys_API::keys();

        Redsys::setApiKey($api['api_key']);

        return PaymentRequest::create([
            'amount' => absint($amount),
            'order' => $order_id,
            'merchant_code' => $api['merchant_code'],
            'terminal' => $api['terminal'],
            'merchant_url' => $return_url . '&wpbs_redsys_payment_webhook',
            'url_ok' => $return_url . '&wpbs_redsys_payment_succeeded&wpbs_redsys_order_id=' . urlencode($order_id),
            'url_ko' => $return_url . '&wpbs_redsys_payment_failed',
            'paymethods' => $paymethods
        ]);
    }

    public function getPaymentData()
    {

        $api = WPBS_Redsys_API::keys();

        $content_type = $_SERVER['CONTENT_TYPE'] ?? 'application/x-www-form-urlencoded';

        Webhook::setContentType($content_type);

        $payload = $content_type == 'application/x-www-form-urlencoded' ?
        $_POST :
        @file_get_contents('php://input');

        Webhook::verifySignature($payload, $api['api_key']);

        return Webhook::getData($payload);
    }
}
